.. include:: readme.rst

.. toctree::
   :hidden:
   :maxdepth: 1

   installation
   quickstart
   tutorials
   performance
   faqs/index
   updates_from_v3
   acknowledge

.. toctree::
   :caption: API Reference
   :hidden:
   autoapi/py21cmfast/index

.. toctree::
   :hidden:
   :caption: Development

   developer_install
   contributing
   notes_for_developers
   license
   changelog
   authors
